@@ -36,6 +36,7 @@ type Writer interface {
 	WriteExplicitLineBreak(ExplicitLineBreak)
 	WriteLineBreak(LineBreak)
 	WriteRegularLink(RegularLink)
+	WriteMacro(Macro)
 	WriteTimestamp(Timestamp)
 	WriteFootnoteLink(FootnoteLink)
 	WriteFootnoteDefinition(FootnoteDefinition)
@@ -95,6 +96,8 @@ func WriteNodes(w Writer, nodes ...Node) {
 			w.WriteLineBreak(n)
 		case RegularLink:
 			w.WriteRegularLink(n)
+		case Macro:
+			w.WriteMacro(n)
 		case Timestamp:
 			w.WriteTimestamp(n)
 		case FootnoteLink:
